#!/usr/local/bin/php
<?php
/**
 * $Horde: luxor/scripts/genxref.php,v 1.9 2005/01/03 14:35:14 jan Exp $
 *
 * Copyright 2003-2005 Jan Schneider <jan@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.horde.org/licenses/gpl.php.
 */

// Find the base file path of Horde.
@define('HORDE_BASE', dirname(__FILE__) . '/../..');

// Do CLI checks and environment setup first.
require_once HORDE_BASE . '/lib/core.php';
require_once 'Horde/CLI.php';

// Make sure no one runs this from the web.
if (!Horde_CLI::runningFromCLI()) {
    exit("Must be run from the command line\n");
}

// Load the CLI environment - make sure there's no time limit, init
// some variables, etc.
Horde_CLI::init();

// Now go ahead and load Luxor.
$session_control = 'none';
@define('AUTH_HANDLER', true);
@define('LUXOR_BASE', dirname(__FILE__) . '/..');
require_once LUXOR_BASE . '/lib/base.php';
require_once LUXOR_BASE . '/lib/Tagger.php';
require_once 'Horde/CLI.php';

// This script may run a long time.
@set_time_limit(0);

$cli = &new Horde_CLI();
ob_implicit_flush(true);

$first = true;
foreach ($sources as $sourceid => $source) {
	$index = &Luxor_Driver::singleton($sourceid);
	$files = &Luxor_Files::singleton($source['driver'], $source);

	// Clear old data out of the database.
	if ($first) {
		$index->clearIndex();
		$first = false;
	}

	// Index files.
	$cli->writeln($cli->bold(sprintf(_("Indexing %s"), $source['name'])));
	genindex($files, '/');
	$cli->writeln();

	// Reference files.
	$cli->writeln($cli->bold(sprintf(_("Referencing %s"), $source['name'])));
	genrefs($files, '/');
	gensearch();
	$cli->writeln();
}

$cli->writeln($cli->green("DONE"));


/**
 * Functions.
 */
function genindex($files, $path)
{
    global $cli;

    $cli->writeln("*** $path");
    if (substr($path, -1, 1) == '/') {
        $dirs = $files->getDir($path);
        if (is_a($dirs, 'PEAR_Error')) {
            $cli->writeln($cli->red($dirs->getMessage()));
            return;
        }
        foreach ($dirs as $dir) {
            genindex($files, $path . $dir);
        }
    } else {
        $result = Luxor_Tagger::processFile($files, $path);
        if (is_a($result, 'PEAR_Error')) {
            $cli->writeln($cli->red($result->getMessage()));
            return;
        }
    }
}

function genrefs($files, $path)
{
    global $cli;

    $cli->writeln("### $path");
    if (substr($path, -1, 1) == '/') {
        $dirs = $files->getDir($path);
        if (is_a($dirs, 'PEAR_Error')) {
            $cli->writeln($cli->red($dirs->getMessage()));
            return;
        }
        foreach ($dirs as $dir) {
            genrefs($files, $path . $dir);
        }
    } else {
        $result = Luxor_Tagger::processRefs($files, $path);
        if (is_a($result, 'PEAR_Error')) {
            $cli->writeln($cli->red($result->getMessage()));
            return;
        }
    }
}

function gensearch()
{
}
