<?php
/**
 * $Horde: luxor/source.php,v 1.41 2005/01/03 14:35:14 jan Exp $
 *
 * Copyright 2003-2005 Jan Schneider <jan@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.horde.org/licenses/gpl.php.
 */

function printdir($dir)
{
    global $files, $notification;

    $template = &new Horde_Template(LUXOR_BASE . '/templates/');
    $template->set('name', _("Name"));
    $template->set('size', _("Size"));
    $template->set('date', _("Date (GMT)"));
    $template->set('description', _("Description"));

    // Alternate the color highlighting.
    $dirlist = Luxor::dirExpand($dir);
    if (is_a($dirlist, 'PEAR_Error')) {
        $notification->push($dirlist, 'horde.error');
        return;
    }
    $i = 0;
    foreach ($dirlist as $id => $file) {
        $dirlist[$id]['css'] = 'item' . ($i % 2);
        $i++;
    }
    $template->set('files', $dirlist);

    $output = $template->fetch('source/dir.inc');
    $output .= Luxor::dirDesc($files, $dir);

    return $output;
}

function printfile($pathname, $raw = false)
{
    global $conf, $notification, $lastmod, $raw;

    if (substr($pathname, -1) == '/') {
        return printdir($pathname);
    }

    if (Luxor::isRestricted($pathname)) {
        $notification->push(sprintf(_("You do not have permission to view %s."), $pathname), 'horde.error');
        return;
    }

    require_once 'Horde/Cache.php';
    $cache = &Horde_Cache::singleton($conf['cache']['driver'], Horde::getDriverConfig('cache', $conf['cache']['driver']));
    if (is_a($cache, 'PEAR_Error')) {
       	Horde::fatal($cache, __FILE__, __LINE__);
    }

    if ($raw) {
        $key = 'luxor_' . $pathname . '_raw';
        $output = $cache->get($key, time() - $lastmod);
        if (!$output) {
            $output = printfile_raw();
            $cache->set($key, $output);
        }
    } else {
        $key = 'luxor_' . $pathname;
        $output = $cache->get($key, time() - $lastmod);
        if (!$output) {
            $output = printfile_markup();
            $cache->set($key, $output);
        }
    }

    return $output;
}

function printfile_markup()
{
	global $pathname, $files, $notification, $raw;

	$ann = $files->getAnnotations($pathname);
	/*  Commented out until we have a driver that supports annotations.
        this formating should probably be done in markupFile();
        if (is_array($ann)) {
            $b = null;
            for ($i = 0; $i < count($ann); $i++) {
                if ($ann[$i] == $b) {
                    $ann[$i] = str_repeat(' ', 16);
                    continue;
                }
                $b = $ann[$i];
                $ann[$i] .= str_repeat(' ', 6 - strlen($ann[$i])) . $files->getAuthor($pathname);
                $ann[$i] .= str_repeat(' ', 16 - strlen($ann[$i]));
            }
        }
	*/

	$fileh = $files->getFileHandle($pathname);
	if (!$fileh) {
		$notification->push(sprintf(_("The file %s can't be opened or doesn't exist."), $pathname), 'horde.error');
		return;
	}

	$output = Luxor::markupFile($pathname, $fileh, $ann);
	if ($output === false) {
		$notification->push(sprintf(_("Could not markup file %s."), $pathname), 'horde.warning');
		$raw = true;
	} else {
		return $output;
	}
}

function printfile_raw()
{
	global $mime_drivers, $mime_drivers_map, $pathname, $files;

	require_once 'Horde/MIME/Magic.php';
	require HORDE_BASE . '/config/mime_drivers.php';
	require LUXOR_BASE . '/config/mime_drivers.php';
	require_once 'Horde/MIME/Viewer.php';
	require_once 'Horde/MIME/Part.php';

	$filename = $files->toReal($pathname);
	$fp = fopen($filename, 'r');
	$data = fread($fp, filesize($filename));
	fclose($fp);

	$mime_part = &new Mime_Part(MIME_Magic::filenameToMIME($pathname), $data);
	$mime_part->setName($pathname);
	$viewer = &MIME_Viewer::factory($mime_part);

	if ($viewer->getType() == 'text/plain') {
		return '<pre class="fixed">' . htmlspecialchars($viewer->render()) . '</pre>';
	} else {
		return $viewer->render();
	}
}

@define('LUXOR_BASE', dirname(__FILE__));
require_once LUXOR_BASE . '/lib/base.php';
require_once 'Horde/Template.php';

if (substr($pathname, -5) == '.html' ||
    substr($pathname, -4) == '.htm' ||
    Util::getFormData('raw')) {
    echo printfile($pathname, true);
    exit;
}

$lastmod = $index->getLastModified($pathname);
$content = printfile($pathname);

if (substr($pathname, -1) == '/') {
	$title = sprintf(_("Directory Listing :: %s"), $pathname);
} else {
	$title = sprintf(_("Markup of %s"), $pathname);
	if ($lastmod) {
		$mod_gmt = gmdate('D, d M Y H:i:s', $lastmod) . ' GMT';
		header('Last-Modified: ' . $mod_gmt);
		header('Cache-Control: public, max-age=86400');
	}

	Horde::addScriptFile('show_var.js', 'luxor', true);
}

if (is_a($content, 'PEAR_Error')) {
    $notification->push($content->getMessage(), 'horde.error');
}

require LUXOR_TEMPLATES . '/common-header.inc';
require LUXOR_TEMPLATES . '/menu.inc';
require LUXOR_TEMPLATES . '/headerbar.inc';
if (!is_a($content, 'PEAR_Error')) {
    echo $content;
}
require $registry->get('templates', 'horde') . '/common-footer.inc';
